#! /bin/sh
# MediaServer Control File written by Itzchak Rehberg
###############################################################################
#==================================================================[ Setup ]===
DAEMON=mediaserver
WORKDIR=/usr/local/mediaserver
MSERV=${WORKDIR}/${DAEMON}
PIDFILE=/var/run/mediaserver.pid

#=================================================================[ Script ]===
. /etc/rc.status
rc_reset

cd $WORKDIR
case "$1" in
  start)
    if [ -e $PIDFILE ]; then
      PID=`cat $PIDFILE`
      echo "Twonky MediaServer seems already be running under PID $PID"
      echo "(PID file $PIDFILE already exists). Checking for process..."
      running=`ps --no-headers -o "%c" -p $PID`
      if ( [ "${DAEMON}"=="${running}" ] ); then
        echo "Process IS running. Not started again."
      else
        echo "Looks like the daemon crashed: the PID does not match the daemon."
        echo "Removing flag file..."
        rm $PIDFILE
        $0 start
        exit 0
      fi
      exit 1
    else
      echo -n "Starting "
      $MSERV -D
      rc_status -v
    fi
  ;;
  stop)
    if [ ! -e $PIDFILE ]; then
      echo "PID file $PIDFILE not found, nothing to stop."
      echo "Probably you did not start the server?"
      exit 1
    else
      echo -n "Stopping Twonky MediaServer..."
      PID=`cat $PIDFILE`
      kill -s TERM $PID
      rm -f $PIDFILE
      rc_status -v
    fi
  ;;
  reload)
    if [ ! -e $PIDFILE ]; then
      echo "PID file $PIDFILE not found, nothing to stop."
      echo "Probably you did not start the server?"
      exit 1
    else
      echo -n "Reloading Twonky MediaServer..."
      PID=`cat $PIDFILE`
      kill -s HUP $PID
      rc_status -v
    fi
  ;;
  restart)
    $0 stop
    $0 start
  ;;
  *)
    echo ""
    echo "Twonky MediaServer"
    echo "------------------"
    echo "Syntax:"
    echo "  $0 {start|stop|restart|reload}"
    echo ""
    exit 1
  ;;
esac
rc_exit
